@@ -2,6 +2,7 @@ import os
 import logging
 import json
 import boto3
+from token_bucket import Limiter, MemoryStorage
 
 logger = logging.getLogger(__name__)
 
@@ -16,11 +17,13 @@ def lambda_handler(event, _):
     logger.info(json.dumps(event))
     logger.info(f"LOG_LEVEL: {log_level} ")
 
+    limiter = Limiter(rate=10, capacity=10, storage=MemoryStorage)
     if 'Records' in event:
         for record in event['Records']:
             if record["eventSource"] == "aws:sqs":
                 body = json.loads(record["body"])
                 token = body['TaskToken']
+                limiter.consume(key="bla")
                 step_functions_client.send_task_success(
                     taskToken=token,
                     output=json.dumps(
